@@ -3,6 +3,7 @@
 import json,spacy,os,builtins
 from spacy.tokens import DocBin,Doc,Token
 from spacy.tokenizer import Tokenizer
+from spacy.matcher import Matcher
 from spacy.lang.char_classes import ALPHA, ALPHA_LOWER, ALPHA_UPPER, CONCAT_QUOTES, LIST_ELLIPSES, LIST_ICONS
 from spacy.util import compile_infix_regex
 
@@ -65,7 +66,6 @@ def from_docbin(bs):
 
 if not hasattr(spacy, 'nlp'):
 	spacy.nlp		= spacy.load('en_core_web_sm') 
-	spacy.merge_nps	= spacy.nlp.create_pipe("merge_noun_chunks")
 	spacy.tobs		= to_docbin # for old codes
 	spacy.frombs	= from_docbin
 	spacy.nlp.tokenizer = custom_tokenizer(spacy.nlp)	#nlp.tokenizer.infix_finditer = infix_re.finditer
@@ -104,6 +104,8 @@ def common_perc(snt="She has ready.", trans="She is ready."):
 	toks = set([t.text for t in spacy.nlp.tokenizer(snt)])
 	return len([t for t in spacy.nlp.tokenizer(trans) if t.text in toks]) / (len(toks)+0.01)
 
+merge_nps		= lambda : spacy.nlp.create_pipe("merge_noun_chunks")
+new_matcher		= lambda : Matcher(spacy.nlp.vocab) # by exchunk
 toks			= lambda doc:  [{'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_} for t in doc ] # JSONEachRow 
 pred_offset		= lambda doc:  (ar := [ t.i for t in doc if t.dep_ == "ROOT"], offset := ar[0] if len(ar) > 0 else 0,  offset/( len(doc) + 0.1) )[-1]
 postag			= lambda doc:  "_^ " + " ".join([ f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc]) + " _$"
